@@ -51,7 +51,7 @@ def _parse_param(key: str, val: str, param_config: dict):
         _, ext = os.path.splitext(val)
         
         # use numpy for matrix files
-        if ext.lower() == '.mat':
+        if ext.lower() == '.dat':
             val = np.loadtxt(val)
         elif ext.lower() == '.csv':
             val = pd.read_csv(val)
@@ -93,4 +93,4 @@ def parse_parameter() -> dict:
         Use get_parameter instead
     """
     print('[FutureWarning]: parse_parameters is deprecated and will be removed with one of the next releases. Please use get_parameters.')
-    return get_parameter()
\ No newline at end of file
+    return get_parameter()
